@@ -8,15 +8,15 @@ no warnings qw/redefine/;
 
 =head1 NAME
 
-WebService::UMLSKS::Similarity - The great new WebService::UMLS::Similarity!
+WebService::UMLSKS::Similarity - access the Unified Medical Language System (UMLS) via Webservices
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
